ams.opt.OModel
==============

.. currentmodule:: ams.opt

.. autoclass:: OModel

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~OModel.evaluate
       
       
          ~OModel.finalize
       
       
          ~OModel.init
       
       
          ~OModel.parse
       
       
          ~OModel.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~OModel.class_name
      ~OModel.initialized
   
   